@@ -4,6 +4,8 @@ context("test-annotation-map-tile.R")
 if (identical(Sys.getenv("NOT_CRAN"), "true")) {
 
   test_that("annotation_map_tile() works as intended", {
+    skip_if_not_installed("vdiffr")
+
     load_longlake_data(which = "longlake_waterdf")
 
     expect_message(
@@ -121,4 +123,12 @@ if (identical(Sys.getenv("NOT_CRAN"), "true")) {
 
   })
 
+  test_that("annotation_map_tile() does not fail when handed a single point", {
+    p <- sf::st_sf(sf::st_sfc(sf::st_point(c(219200, 629650)), crs = 2039)) %>%
+      ggplot() +
+      annotation_map_tile() +
+      geom_sf()
+
+    expect_warning(ggplot2::ggplotGrob(p), "bounding box is too small")
+  })
 }
